import React, { useState } from "react";
import { FaBars, FaTimes } from "react-icons/fa";
import Button from "../button/Button";
import NavItem from "./NavItem";
import { useSession, signOut } from "next-auth/react";

const Navigation = ({
  siteTitle,
  siteLogo,
  profileImg,
  profileIcon,
  navShow,
}) => {
  //user session
  const { data: session } = useSession();
  //set menu show
  const [showMenu, setShowMenu] = useState(false);
  //handle navigation
  const handleShowMenu = () => setShowMenu((showMenu) => !showMenu);
  //mobile menu class
  const mobileHeaderClass =
    "z-20 w-full h-screen bg-white flex flex-col justify-center items-center drop-shadow-xl";
  const mobileNavClass =
    "w-full h-[70%] text-textColor flex flex-col justify-around items-center";
  const mobileMenuClass =
    "h-full flex flex-col justify-around items-center gap-5";

  return (
    <header
      className={
        showMenu
          ? mobileHeaderClass
          : "w-full bg-white flex flex-col justify-center items-center"
      }
    >
      <div className="w-full h-[80px] md:m-0 m-auto flex md:justify-center justify-center items-center drop-shadow-xl md:border-b-2 border-b-gray-200 border-b-0">
        {siteLogo && (
          <img src={siteLogo} className="w-[100px] h-full object-cover" />
        )}
      </div>

      <nav
        className={
          showMenu
            ? mobileNavClass
            : "w-full md:h-[80px] h-0 bg-white text-textColor md:flex justify-around items-center border-b-2 border-gray-200"
        }
      >
        {!showMenu ? (
          <>
            <FaBars
              className="lg:hidden block absolute text-3xl top-[25px] left-[20px] cursor-pointer hover:text-btnOutline transition-colors duration-200"
              onClick={handleShowMenu}
            />
            <a href="">
              <div className="absolute lg:hidden block top-[20px] right-[15px] w-[60px] h-[60px]">
                {profileImg && (
                  <img
                    src={profileImg}
                    className="w-full h-full object-cover"
                  />
                )}
                {profileIcon && profileIcon}
              </div>
            </a>
          </>
        ) : (
          <FaTimes
            className="lg:hidden block absolute  text-3xl top-[40px] left-[20px] cursor-pointer hover:text-btnOutline transition-colors duration-200"
            onClick={handleShowMenu}
          />
        )}
        <div className="w-full h-full grid md:grid-cols-12  md:flex-col justify-center md:items-center items-start">
          <div className="col-span-1 md:col-span-12 flex flex-col justify-center items-center">
            <ul
              className={
                showMenu
                  ? mobileMenuClass
                  : "w-11/12 lg:flex justify-center items-center hidden gap-8"
              }
            >
              <NavItem name="MEN" link="/models?gender=male" />
              <NavItem name="WOMEN" link="/models?gender=female" />
              <NavItem name="SCOUTING" link="/get-scouted" />
              <NavItem name="CONTACT" link="/contact-us" />
            </ul>
          </div>
        </div>
      </nav>
    </header>
  );
};

export default Navigation;
