import React, { useState } from "react";
import { useModel } from "@/hooks/model";
import InputField from "@/components/UI/input/InputField";
import Button from "@/components/UI/button/Button";
import CircleLoader from "@/components/UI/loader/circle/CircleLoader";
const AddModel = () => {
  //use hook
  const { addModel } = useModel();
  //set loading state
  const [loading, setLoading] = useState(false);
  //set url
  const [url, setUrl] = useState(null);
  //set all input fields
  const [inputs, setInputs] = useState({
    name: "",
    gender: "",
    height: "",
    bust: "",
    waist: "",
    hips: "",
    dress: "",
    shoes_size: "",
    hair: "",
    eyes: "",
    profile_photo: null,
    instagram_id_link: "",
  });
  // InputValidationErrors
  const [validationErrors, setValidationErrors] = useState({});
  //define errors
  const [errors, setErrors] = useState([]);
  //handleInputChange
  const handleInputChange = (e) => {
    setInputs({ ...inputs, [e.target.name]: e.target.value });
  };
  //handle uploadFileChange
  const handleUploadFileChange = (e) => {
    // Get the selected file (only one file)
    const file = e.target.files[0];
    // this gives us the data on what files are selected
    if (file) {
      console.log("[file]", file);
      // transform files into data urls
      const url = URL.createObjectURL(file);
      //set image url
      setUrl(url);
      //set image url in state
      setInputs({ ...inputs, [e.target.name]: file });
    }
  };
  //check input validation
  const validate = (inputValues) => {
    const errors = {};
    const usernameRegex = /^[A-Za-z0-9]{3,16}$/;
    const emailRegex =
      /^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i;

    if (!inputValues.name) {
      errors.name = "Model Name is required";
    } else if (!usernameRegex.test(inputValues.username)) {
      errors.name =
        "Model Name should be 3-16 characters and shouldn't include any special character";
    }
    if (!inputValues.height) {
      errors.height = "Model Height is required";
    }
    if (!inputValues.gender) {
      errors.gender = "Model Gender is required";
    }
    if (!inputValues.bust) {
      errors.bust = "Model Bust is required";
    }
    if (!inputValues.waist) {
      errors.waist = "Model Waist is required";
    }
    if (!inputValues.hips) {
      errors.hips = "Model Hips is required";
    }
    if (!inputValues.dress) {
      errors.dress = "Model Dress is required";
    }
    if (!inputValues.shoes_size) {
      errors.shoes_size = "Model Shoe Size is required";
    }
    if (!inputValues.hair) {
      errors.hair = "Model Hair is required";
    }
    if (!inputValues.eyes) {
      errors.eyes = "Model Eyes is required";
    }
    if (!inputValues.profile_photo) {
      errors.profile_photo = "Model Profile Photo is required";
    }
    return errors;
  };
  //check validation error object
  const isObjectEmpty = (objectName) => {
    return (
      objectName &&
      Object.keys(objectName).length === 0 &&
      objectName.constructor === Object
    );
  };
  //submit the data in backend
  const handleSubmit = (event) => {
    //event is an event object
    event.preventDefault();
    //client-side validation
    const errors = validate(inputs);
    //set validation error in state object
    setValidationErrors(errors);
    if (!isObjectEmpty(errors)) {
      //if any errors occur return null and do not submit the input values
      return;
    } else {
      const {
        name,
        height,
        gender,
        bust,
        waist,
        hips,
        dress,
        shoes_size,
        hair,
        eyes,
        profile_photo,
        instagram_id_link,
      } = inputs;
      // here you calling your submit api
      addModel({
        setLoading,
        setErrors,
        name,
        gender,
        height,
        bust,
        waist,
        hips,
        dress,
        shoes_size,
        hair,
        eyes,
        profile_photo,
        instagram_id_link,
      });

      //dispatch action when you use redux

      //reset form
      setInputs({
        name: "",
        gender: "",
        height: "",
        bust: "",
        waist: "",
        hips: "",
        dress: "",
        shoes_size: "",
        hair: "",
        eyes: "",
        profile_photo: null,
        instagram_id_link: "",
      });
    }
  };
  return (
    <>
      {loading ? (
        <CircleLoader />
      ) : (
        <div className="w-full bg-white p-4 flex flex-col justify-center items-center rounded-md mt-10 gap-5">
          <h2 className="font-textImpact text-center">ADD MODEL</h2>
          <form className="w-[85%] flex flex-col justify-center items-center gap-3" onSubmit={handleSubmit}>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="name"
                  placeholder="Model Name"
                  value={inputs.name}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["name"]}
                />
              </div>
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="height"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  placeholder="Model Height"
                  value={inputs.height}
                  onChange={handleInputChange}
                  errorMessage={validationErrors["height"]}
                />
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="gender"
                  placeholder="Model Gender"
                  value={inputs.gender}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["gender"]}
                />
              </div>
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="bust"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  placeholder="Model Bust"
                  value={inputs.bust}
                  onChange={handleInputChange}
                  errorMessage={validationErrors["bust"]}
                />
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="waist"
                  placeholder="Model Waist"
                  value={inputs.waist}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["waist"]}
                />
              </div>
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="hips"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  placeholder="Model Hips"
                  value={inputs.hips}
                  onChange={handleInputChange}
                  errorMessage={validationErrors["hips"]}
                />
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="dress"
                  placeholder="Model Dress"
                  value={inputs.dress}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["dress"]}
                />
              </div>
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="shoes_size"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  placeholder="Model Shoe Size"
                  value={inputs.shoes_size}
                  onChange={handleInputChange}
                  errorMessage={validationErrors["shoes_size"]}
                />
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="hair"
                  placeholder="Model Hair"
                  value={inputs.hair}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["hair"]}
                />
              </div>
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="eyes"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  placeholder="Model Eyes"
                  value={inputs.eyes}
                  onChange={handleInputChange}
                  errorMessage={validationErrors["eyes"]}
                />
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="instagram_id_link"
                  placeholder="Model Instagram ID"
                  value={inputs.instagram_id_link}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["instagram_id_link"]}
                />
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="file"
                  name="profile_photo"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  onChange={handleUploadFileChange}
                  errorMessage={validationErrors["profile_photo"]}
                />
              </div>
              <div className="col-span-6">
                <div className="relative w-[85%] h-[300px] m-5">
                  <img
                    src={url}
                    className="absolute w-full h-full object-contain"
                  />
                </div>
              </div>
            </div>
            <Button text="ADD MODEL" />
          </form>
        </div>
      )}
    </>
  );
};

export default AddModel;
