import React, { useEffect, useState } from "react";
import CustomPagination from "@/components/UI/pagination/CustomPagination";
import { FaRegEdit } from "react-icons/fa";
import { MdDelete } from "react-icons/md";
import { useModel } from "@/hooks/model";
import { toast } from "react-toastify";
import EditModel from "./EditModel";
import Button from "@/components/UI/button/Button";
import CircleLoader from "@/components/UI/loader/circle/CircleLoader";
import { useRouter } from "next/router";
const ListModel = () => {
  //fetched models
  const { fetchAllModels } = useModel();
  //use router to get url parameters
  const router = useRouter();
  //extract url parameters
  const { page, keyword, gender, name, height } = router.query;
  //use hook
  const { deleteModel } = useModel();
  //define state
  const [model, setModel] = useState({});
  const [allModels, setAllModels] = useState({});
  const [editModelModal, handleEditModelModal] = useState(false);
  const [loading, setLoading] = useState(false);
  const [deleteModelSuccessStatus, setDeleteModelSuccessStatus] =
    useState(false);
  const [updateModelSuccessStatus, setUpdateModelSuccessStatus] =
    useState(false);

  //---------------------edit model---------------------//
  const handleCloseEditModelModal = () => {
    handleEditModelModal(false);
  };
  const ShowModelEditModal = (model) => {
    handleEditModelModal(true);
    setModel(model);
  };

  useEffect(() => {
    //note delete action
    if (deleteModelSuccessStatus) {
      toast.success("Model Deleted Successfully", {
        position: "top-center",
        autoClose: 5000,
      });
      setDeleteModelSuccessStatus(false);
      setLoading(false);
    }
    if (updateModelSuccessStatus) {
      toast.success("Model Updated Successfully", {
        position: "top-center",
        autoClose: 5000,
      });
      setUpdateModelSuccessStatus(false);
      setLoading(false);
    }
    fetchAllModels({ page, keyword, gender, name, height, setAllModels });

  }, [deleteModelSuccessStatus, updateModelSuccessStatus]);

  const {per_page, total, data}=allModels

  return (
    <>
      {loading ? (
        <CircleLoader />
      ) : (
        <div class="w-full h-screen bg-white flex flex-col justify-start items-center relative overflow-x-auto mt-10">
          <table class="w-full text-sm text-left rtl:text-right text-gray-500 dark:text-gray-400">
            <thead class="text-xs text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
              <tr>
                <th scope="col" class="px-6 py-3">
                  No
                </th>
                <th scope="col" class="px-6 py-3">
                  Name
                </th>
                <th scope="col" class="px-6 py-3">
                  Gender
                </th>
                <th scope="col" class="px-6 py-3">
                  Height
                </th>
                <th scope="col" class="px-6 py-3">
                  Bust
                </th>
                <th scope="col" class="px-6 py-3">
                  Waist
                </th>
                <th scope="col" class="px-6 py-3">
                  Hips
                </th>
                <th scope="col" class="px-6 py-3">
                  Dress
                </th>
                <th scope="col" class="px-6 py-3">
                  Shoes Size
                </th>
                <th scope="col" class="px-6 py-3">
                  Profile
                </th>
                <th scope="col" class="px-6 py-3" colSpan={2}>
                  Action
                </th>
              </tr>
            </thead>
            <tbody>
              {data &&
                data.map((model) => {
                  return (
                    <tr>
                      <td className="px-6 py-4">{model.id}</td>
                      <td className="px-6 py-4">{model.name}</td>
                      <td className="px-6 py-4">{model.gender}</td>
                      <td className="px-6 py-4">{model.height}</td>
                      <td className="px-6 py-4">{model.bust}</td>
                      <td className="px-6 py-4">{model.waist}</td>
                      <td className="px-6 py-4">{model.hips}</td>
                      <td className="px-6 py-4">{model.dress}</td>
                      <td className="px-6 py-4">{model.shoes_size}</td>
                      <td className="px-6 py-4">
                        <img src={model.profile_photo} />
                      </td>
                      <td className="px-6 py-4">
                        <Button>
                          <FaRegEdit
                            className="fs-1"
                            onClick={() => ShowModelEditModal(model)}
                          />
                        </Button>
                      </td>
                      <td className="px-6 py-4">
                        <Button>
                          <MdDelete
                            className="fs-1"
                            onClick={() =>
                              deleteModel({
                                id: model.id,
                                setDeleteModelSuccessStatus,
                                setLoading,
                              })
                            }
                          />
                        </Button>
                      </td>
                    </tr>
                  );
                })}
            </tbody>
          </table>
          {editModelModal && (
            <EditModel
              onClose={handleCloseEditModelModal}
              model={model}
              isEditModel={editModelModal}
              setIsEditModel={handleEditModelModal}
              setUpdateModelSuccessStatus={setUpdateModelSuccessStatus}
              setAllModels={setAllModels}
            />
          )}
        </div>
      )}
    </>
  );
};

export default ListModel;
