import { useSliderImage } from "@/hooks/slider";
import React, { useState, useEffect } from "react";
import CircleLoader from "@/components/UI/loader/circle/CircleLoader";
import Button from "@/components/UI/button/Button";
import ModelCard from "../model-photo/ModelCard";
import { toast } from "react-toastify";

const ListSliderImage = () => {
  const { fetchAllSliderPhotos, deleteSliderPhoto  } = useSliderImage();
  //use state
  const [loading, setLoading] = useState(false);
  const [allSliderPhotos, setAllSliderPhotos] = useState([]);
  const [deleteSliderPhotoSuccess, setDeleteSliderPhotoSuccess] = useState(false);

  useEffect(() => {
    //note delete action
    if (deleteSliderPhotoSuccess) {
      toast.success("Slider Photo Deleted Successfully", {
        position: "top-center",
        autoClose: 5000,
      });
      setDeleteSliderPhotoSuccess(false);
      setLoading(false);
    }

    fetchAllSliderPhotos(setAllSliderPhotos);
  }, [deleteSliderPhotoSuccess]);

  console.log("[sliders]", allSliderPhotos);

  return (
    <>
      {loading ? (
        <CircleLoader />
      ) : (
        <div class="w-full max-h-screen bg-white flex flex-col justify-start items-center relative overflow-y-scroll scroll-smooth my-5 gap-4">
          <h2 className="text-center text-black py-4 font-textImpact">
            SLIDER PHOTO LIST
          </h2>
          <a href="/admin/slider/add">
            {" "}
            <Button text="ADD SLIDER PHOTO" />
          </a>
          <div className="w-full h-full grid grid-cols-[300px_300px_300px_300px] grid-rows-auto gap-1 justify-center items-center">
            {allSliderPhotos &&
              allSliderPhotos.length > 0 &&
              allSliderPhotos.map((photo) => {
                return (
                  <ModelCard
                    ImgSrc={photo.image}
                    onDelete={() =>
                        deleteSliderPhoto({
                        id: photo.id,
                        setLoading,
                        setDeleteSliderPhotoSuccess,
                      })
                    }
                  />
                );
              })}
          </div>
        </div>
      )}
    </>
  );
};

export default ListSliderImage;
