import React, { useEffect, useRef, useState } from "react";
import { useRouter } from "next/router";
import { toast } from "react-toastify";
import Warning from "./Warning";
import { useModel } from "@/hooks/model";
import InputField from "../UI/input/InputField";
import UploadImage from "./UploadImage";
import Button from "../UI/button/Button";
const GetScouted = () => {
  //use hook
  const router = useRouter();
  //use post api
  const { postModelApplication } = useModel();
  //post model application status
  const [postModelApplicationStatus, setPostModelApplicationStatus] =
    useState(false);

  const [showApplicationModal, handleShowApplicationModal] = useState(false);

  const handleCloseApplicationModal = () => {
    handleShowApplicationModal(false);
  };
  const ShowApplicationModal = () => {
    handleShowApplicationModal(true);
  };
  //background video ref
  const backgroundVideoRef = useRef();
  //warning overlay ref
  const warningOverlay = useRef();
  //file1
  const file1Ref = useRef();
  //file2
  const file2Ref = useRef();
  //file3
  const file3Ref = useRef();
  //define show warning
  const [showWarning, setShowWarning] = useState(true);
  //define loading
  const [loading, setLoading] = useState(false);
  //define errors
  const [errors, setErrors] = useState([]);
  //define validation errors state
  const [validationErrors, setValidationErrors] = useState({});
  //set files
  const [files, setFiles] = useState([]);
  //all input values
  const [inputs, setInputs] = useState({
    email: "",
    first_name: "",
    last_name: "",
    height: "",
    birth_date: "",
    nationality: "",
    question: "",
    instagram: "",
    tiktok: "",
    image1: null,
    image2: null,
    image3: null,
  });
  //handleInput Values
  const handleInputChange = (e) => {
    setInputs({ ...inputs, [e.target.name]: e.target.value });
  };
  //handle uploadFileChange
  const handleUploadFileChange = (e) => {
    const file = e.target.files[0]; // Get the selected file (only one file)

    if (file) {
      setFiles((prevFiles) => [...prevFiles, file]); // Append the new file to the state array
    }
    // this gives us the data on what files are selected
    // however, it's of type `FileList` which is hard to modify.
    const fileList = e.target.files;
    // let's convert `FileList` into a `File[]`
    if (fileList) {
      const files = [...fileList]; // now we have `File[]` type
      // This only works on es6 version make sure to set your tsconfig.json "target" to "es6"
      //   onFilesChange(files);

      // console.log("[file]", files);

      // setInputValues({...inputValues, [e.target.name]:files})
      setInputs({ ...inputs, [e.target.name]: files });
    }
  };

  // transform files into data urls
  const urls = files && files.map((file) => URL.createObjectURL(file));

  //handling input errors
  const validate = (inputValues) => {
    const errors = {};
    const emailRegex =
      /^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i;
    const passwordRegex =
      /^(?=.*[0-9])(?=.*[a-zA-Z])(?=.*[!@#$%^&*])[a-zA-Z0-9!@#$%^&*]{8,20}$/;
    const regex = /^[^\s@]+@[^\s@]+\.[^\s@]{2,}$/i;

    if (!inputValues.first_name) {
      errors.first_name = "First Name is required";
    }
    if (!inputValues.last_name) {
      errors.last_name = "Last Name is required";
    }
    if (!inputValues.email) {
      errors.email = "Email is required";
    } else if (!emailRegex.test(inputValues.email)) {
      errors.email = "It should be a valid email address";
    }
    if (!inputValues.height) {
      errors.height = "Height is required";
    }
    if (!inputValues.birth_date) {
      errors.birth_date = "Date of Birth is required";
    }
    if (!inputValues.nationality) {
      errors.nationality = "Nationality is required";
    }
    if (!inputValues.question) {
      errors.question = "Question is required";
    }
    return errors;
  };
  //check error object for
  const isObjectEmpty = (objectName) => {
    return (
      objectName &&
      Object.keys(objectName).length === 0 &&
      objectName.constructor === Object
    );
  };

  const handleSubmit = async (event) => {
    //set event defaults
    event.preventDefault();
    //set send
    let sendBtn = document.getElementById("sendBtn");
    //client-side validation
    const errors = validate(inputs);
    //set validation errors
    setValidationErrors(errors);
    //check validation errors
    if (!isObjectEmpty(errors)) {
      return;
    } else {
      ShowApplicationModal();
      //set loading true
      // setLoading(true);
      //distructrue the values
      const {
        email,
        first_name,
        last_name,
        height,
        birth_date,
        nationality,
        question,
        instagram,
        tiktok,
        image1,
        image2,
        image3,
      } = inputs;

      setPostModelApplicationStatus(true);
      //send all data in backend api
      // postModelApplication({
      //   setLoading,
      //   setErrors,
      //   setPostModelApplicationStatus,
      //   email,
      //   first_name,
      //   last_name,
      //   height,
      //   birth_date,
      //   nationality,
      //   question,
      //   instagram,
      //   tiktok,
      //   image1: image1[0],
      //   image2: image2[0],
      //   image3: image3[0],
      // });
      //reset form
      setInputs({
        email: "",
        first_name: "",
        last_name: "",
        height: "",
        birth_date: "",
        nationality: "",
        question: "",
        instagram: "",
        tiktok: "",
        image1: null,
        image2: null,
        image3: null,
      });
    }
  };

  useEffect(() => {}, [postModelApplicationStatus]);

  const handleWarning = () => {
    setShowWarning(false);
    if (warningOverlay.current) {
      warningOverlay.current.style.display = "none";
    }
  };

  return (
    <div className="relative w-full flex flex-col justify-center items-center">
      <div
        className="fixed top-0 left-0 w-full h-full flex justify-center items-center bg-black opacity-95 z-30"
        ref={warningOverlay}
      >
        {showWarning && <Warning onClick={handleWarning} />}
      </div>
      <div className="relative w-full h-full overflow-hidden drop-shadow-lg">
        <video
          ref={backgroundVideoRef}
          autoPlay
          loop
          muted
          playsInline
          className="relative w-full h-full outline-none object-cover"
          webkit-playsinline="true" // WebKit-specific attribute for inline play
        >
          <source src="/assets/videos/scout/hero.mp4" type="video/mp4" />
        </video>
      </div>
      <h3 className="absolute md:top-[15%] top-[1%] text-center md:w-[50%] w-[80%] text-white md:text-[100px] text-[40px] font-textImpact z-5 uppercase mx-auto">
        you are <br />
        truly worthy
      </h3>
      <form
        onSubmit={handleSubmit}
        className="w-full flex flex-col justify-center items-center bg-white text-gray-500 gap-3"
      >
        <div className="md:w-[70%] w-[85%] flex flex-col justify-center items-center my-5 mx-auto">
          <h3 className="w-full static text-left md:text-[80px] text-3xl font-textImpact my-5">
            JOIN WORTH MODELS
          </h3>
          <p className="static text-gray-500 text-left text-[22px] font-baskerville my-5">
            Interested in becoming an Worth Model? Get scouted by completing the
            form below and submitting your photos where requested. Our team will
            review your application as soon as possible.
          </p>
          <div className="w-full grid grid-cols-12 justify-center items-center">
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="email"
                placeholder="EMAIL"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-400 font-baskerville"
                value={inputs.email}
                onChange={handleInputChange}
                errorMessage={validationErrors.email}
              />
            </div>
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="first_name"
                placeholder="FIRST NAME"
                value={inputs.first_name}
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-400 font-baskerville"
                onChange={handleInputChange}
                errorMessage={validationErrors.first_name}
              />
            </div>
          </div>
          <div className="w-full grid grid-cols-12 justify-center items-center">
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="last_name"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                placeholder="LAST NAME"
                value={inputs.last_name}
                onChange={handleInputChange}
                errorMessage={validationErrors.last_name}
              />
            </div>
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="height"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                placeholder="HEIGHT"
                value={inputs.height}
                onChange={handleInputChange}
                errorMessage={validationErrors.height}
              />
            </div>
          </div>
          <div className="w-full grid grid-cols-12 justify-center items-center">
            <div className="md:col-span-6 col-span-12">
              <InputField
                label="Birth Date"
                type="date"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                name="birth_date"
                value={inputs.birth_date}
                onChange={handleInputChange}
                errorMessage={validationErrors.birth_date}
              />
            </div>
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="nationality"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                placeholder="NATIONALITY"
                value={inputs.nationality}
                onChange={handleInputChange}
                errorMessage={validationErrors.nationality}
              />
            </div>
          </div>
          <div className="w-full grid grid-cols-12 justify-center items-center">
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="question"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                placeholder="WHERE DO YOU LIVE?"
                value={inputs.question}
                onChange={handleInputChange}
                errorMessage={validationErrors.question}
              />
            </div>
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="instagram"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                placeholder="INSTAGRAM"
                value={inputs.instagram}
                onChange={handleInputChange}
              />
            </div>
          </div>
          <div className="w-full grid grid-cols-12 justify-center items-center">
            <div className="md:col-span-6 col-span-12">
              <InputField
                type="text"
                name="tiktok"
                className="w-11/12 p-4 border-b-2 border-gray-500 focus:outline-none focus:border-b-gray-500 font-baskerville"
                placeholder="TIKTOK"
                value={inputs.tiktok}
                onChange={handleInputChange}
              />
            </div>
            <div className="md:col-span-6 col-span-12"></div>
          </div>
        </div>
        <div className="md:w-[70%] w-[85%] flex flex-col justify-center bg-white text-gray-500 my-5 mx-auto">
          <h3 className="w-full static text-left text-gray-500 text-[80px] font-textImpact">
            SUBMIT YOUR PICTURES
          </h3>
          <p className="text-gray-400 text-left text-[22px] font-baskerville my-5">
            Please avoid wearing baggy clothing, make-up, or smiling. The photos
            you submit should not be filtered, re-touched, or professionally
            taken.
          </p>
          <div className="flex md:flex-nowrap flex-wrap justify-around items-center">
            <UploadImage
              label="1"
              ref={file1Ref}
              name="image1"
              value={inputs.image1}
              onChange={handleUploadFileChange}
              img={urls[0] ? urls[0] : "/assets/images/samples/Upload Full Lenght.JPG"}
              caption="upload head shot"
            />
            <UploadImage
              label="2"
              ref={file2Ref}
              name="image2"
              value={inputs.image2}
              onChange={handleUploadFileChange}
              img={urls[1] ? urls[1] : "/assets/images/samples/Upload Profile.JPG"}
              caption="upload profile"
            />
            <UploadImage
              label="3"
              ref={file3Ref}
              name="image3"
              value={inputs.image3}
              onChange={handleUploadFileChange}
              img={urls[2] ? urls[2] : "/assets/images/samples/Upload Full Lenght.JPG"}
              caption="upload full length"
            />
          </div>
        </div>
        <Button type="submit" text="SUBMIT APPLICATION" className="w-[70%] text-black bg-gray-400 font-textImpact py-4 my-3 " />
        <p className="md:w-[70%] w-[85%] text-gray-400 text-left text-[22px] font-baskerville">
          Safety remains our number one priority and protecting models and
          aspiring models from online predators is of the utmost importance.
          Please do not respond to anyone claiming to be affiliated with Worth
          Models without alerting an adult and verifying their identity first.
          Worth Models never asks for photos in the nude or lingerie and does
          not require any kind of monetary payment. Please don’t hesitate to
          contact us if something doesn’t feel right.
        </p>
      </form>
    </div>
  );
};

export default GetScouted;
