import React, { useEffect, useRef, useState } from "react";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import Slider from "react-slick";
import { FaChevronRight } from "react-icons/fa6";
import { FaChevronLeft } from "react-icons/fa6";
import { FaPlay } from "react-icons/fa";
import VideoItem from "./components/VideoItem";
const HeroVideo = () => {
  const sliderRef = useRef();
  const heroVideo1Ref = useRef();
  const heroVideo2Ref = useRef();
  const heroVideo3Ref = useRef();
  const playButton1Ref = useRef();
  const playButton2Ref = useRef();

  const settings = {
    dots: true,
    infinite: true,
    speed: 500,
    autoplay: false,
    autoplaySpeed: 2500,
    slidesToShow: 1,
    slidesToScroll: 1,
    arrows: false,
    initialSlide: 1,
    beforeChange: () => {
      // Pause all videos before changing the slide
    },
    responsive: [
      {
        breakpoint: 1024,
        settings: {
          slidesToShow: 4,
          slidesToScroll: 1,
          infinite: true,
          dots: true,
        },
      },
      {
        breakpoint: 991,
        settings: {
          slidesToShow: 2,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 768,
        settings: {
          slidesToShow: 2,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 600,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 480,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
    ],
  };

  const ClickNext = () => {
    sliderRef.current.slickNext();
  };

  const ClickPrevious = () => {
    sliderRef.current.slickPrev();
  };

  const handlePlay = () => {
    if (heroVideo1Ref.current) {
      playButton1Ref.current.classList.remove(`${classes.play__button}`);
      playButton1Ref.current.classList.add(`${classes.hidden__button}`);
      heroVideo1Ref.current.muted = false;
      heroVideo1Ref.current.controls = true;
      heroVideo1Ref.current.play();
    } else if (heroVideo2Ref.current) {
      playButton2Ref.current.classList.remove(`.${classes.play__button}`);
      playButton2Ref.current.classList.add(`.${classes.hidden__button}`);
      heroVideo2Ref.current.muted = false;
      heroVideo2Ref.current.controls = true;
      heroVideo2Ref.current.play();
    }
  };

  const handlePause = () => {
    if (heroVideo1Ref.current) {
      playButton1Ref.current.classList.remove(`.${classes.hidden__button}`);
      playButton1Ref.current.classList.add(`.${classes.play__button}`);
      heroVideo1Ref.current.muted = true;
      heroVideo1Ref.current.controls = false;
      heroVideo1Ref.current.pause();
    } else if (heroVideo2Ref.current) {
      playButton2Ref.current.classList.remove(`.${classes.hidden__button}`);
      playButton2Ref.current.classList.add(`${classes.play__button}`);
      heroVideo2Ref.current.muted = true;
      heroVideo2Ref.current.controls = false;
      heroVideo2Ref.current.pause();
    }
  };

  useEffect(() => {}, []);
  return (
    <div className="w-full my-3 mx-auto flex justify-center items-center">
      <FaChevronLeft className="md:text-4xl text-3xl" onClick={ClickPrevious} />
      <Slider
        ref={(slider) => (sliderRef.current = slider)}
        {...settings}
        className="md:w-11/12 w-[85%] flex justify-center items-center py-3 gap-3"
      >
        <VideoItem
          videoSrc="/assets/videos/hero/video1.mp4"
          ref={heroVideo1Ref}
        />
        <VideoItem
          videoSrc="/assets/videos/hero/video2.mp4"
          ref={heroVideo2Ref}
        />
        <VideoItem
          videoSrc="/assets/videos/hero/video3.mp4"
          ref={heroVideo3Ref}
        />
      </Slider>
      <FaChevronRight className="md:text-4xl text-3xl" onClick={ClickNext} />
    </div>
  );
};

export default HeroVideo;
