import React, { useEffect, useRef, useState } from "react";
import Slider from "react-slick";
import { FaChevronRight } from "react-icons/fa6";
import { FaChevronLeft } from "react-icons/fa6";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import SliderItem from "./components/SliderItem";
import { useSliderImage } from "@/hooks/slider";
const Hero = () => {

  //use hook
  const {fetchAllSliderPhotos}=useSliderImage();

  const [allSliderPhotos, setAllSliderPhotos]=useState([])

  const sliderRef = useRef();

  const ClickNext = () => {
    sliderRef.current.slickNext();
  };
  const ClickPrevious = () => {
    sliderRef.current.slickPrev();
  };

  const settings = {
    dots: false,
    infinite: true,
    speed: 500,
    autoplay: true,
    autoplaySpeed: 2500,
    slidesToShow: 4,
    slidesToScroll: 1,
    arrows: false,
    initialSlide: 1,
    responsive: [
      {
        breakpoint: 1024,
        settings: {
          slidesToShow: 4,
          slidesToScroll: 1,
          infinite: true,
          dots: true,
        },
      },
      {
        breakpoint: 991,
        settings: {
          slidesToShow: 2,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 768,
        settings: {
          slidesToShow: 2,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 600,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 480,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
    ],
  };

  useEffect(() => {
    fetchAllSliderPhotos(setAllSliderPhotos)
  }, [])
  


  return (
    <div className="w-full flex justify-center items-center">
      <FaChevronLeft className="md:text-4xl text-3xl" onClick={ClickPrevious} />
      <Slider
        ref={(slider) => (sliderRef.current = slider)}
        {...settings}
        className="md:w-11/12 w-[85%] flex justify-center items-center py-3 gap-3"
      >
        <SliderItem
          imgSrc="/assets/images/hero/AHMED for LEVIS.jpeg"
          name="AHMED for LEVIS"
        />
        <SliderItem
          imgSrc="/assets/images/hero/Alona for MaxFashion.jpeg"
          name="Alona for MaxFashion"
        />
        <SliderItem
          imgSrc="/assets/images/hero/Charly for GQ Magazine.jpeg"
          name="Charly for GQ Magazine"
        />
        <SliderItem
          imgSrc="/assets/images/hero/Ahmed for WIRED.jpeg"
          name="Ahmed for WIRED"
        />
        <SliderItem
          imgSrc="/assets/images/hero/Alona for NETA PORTER.jpeg"
          name="Alona for NETA PORTER"
        />
        <SliderItem
          imgSrc="/assets/images/hero/Yubert for VOGUE Magazine.jpeg"
          name="Yubert for VOGUE Magazine"
        />
        <SliderItem
          imgSrc="/assets/images/hero/Charly for TONY & GUY.jpeg"
          name="Charly for TONY & GUY"
        />
        <SliderItem
          imgSrc="/assets/images/hero/1.1.png"
          name=" Aleksandr for MICHAEL CINCO"
        />
      </Slider>
      <FaChevronRight className="md:text-4xl text-3xl" onClick={ClickNext} />
    </div>
  );
};

export default Hero;
