import React, { useEffect, useRef } from "react";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import Slider from "react-slick";
import { FaChevronRight } from "react-icons/fa6";
import { FaChevronLeft } from "react-icons/fa6";
import Modal from "../UI/modal/Modal";

const ModelView = ({ onClose, images }) => {
  const sliderRef = useRef();

  const ClickNext = () => {
    sliderRef.current.slickNext();
  };
  const ClickPrevious = () => {
    sliderRef.current.slickPrev();
  };

  const settings = {
    dots: false,
    infinite: true,
    speed: 500,
    slidesToShow: 1,
    slidesToScroll: 1,
    arrows: false,
    initialSlide: 1,
    responsive: [
      {
        breakpoint: 1024,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          infinite: true,
          dots: true,
        },
      },
      {
        breakpoint: 991,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 768,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 600,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
      {
        breakpoint: 480,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: 2,
        },
      },
    ],
  };

  useEffect(() => {}, [images]);


  return (
    <Modal
      isOpen
      closed={onClose}
      showCloseButton={true}
      className="bg-white w-full h-screen mx-auto opacity-100 px-10"
    >
      <div className="w-full flex justify-center items-center">
        <FaChevronLeft
          className="text-3xl cursor-pointer"
          onClick={ClickPrevious}
        />
        <Slider
          ref={(slider) => (sliderRef.current = slider)}
          {...settings}
          className="w-11/12 flex justify-center items-center py-5"
        >
          {images &&
            images.map((image, i) => {
              return (
                <div
                  className="w-[80%] py-8 h-[80vh] relative flex justify-center items-center"
                  key={i}
                >
                  <img
                    src={image.image_url}
                    className="w-full h-full object-contain"
                  />
                </div>
              );
            })}
        </Slider>
        <FaChevronRight
          className="text-3xl cursor-pointer"
          onClick={ClickNext}
        />
      </div>
    </Modal>
  );
};

export default ModelView;
