import useSWR from "swr";
import { useEffect, useState } from "react";
import { useRouter } from "next/router";
import HttpService from "@/lib/HttpService";

export const useFavorite = () => {
  //use router to redirect   
  const router = useRouter();
  //use swr to fetch models data
  const [visitor_id, setVisitorId]=useState("")

  console.log("[visitor_id]", visitor_id)
  
  const {
    data: favoriteModels,
    error,
    revalidate,
  } = useSWR(`/model/favorite-list?${visitor_id}`, async () =>
    HttpService.get(`/model/favorite-list?visitor_id=${visitor_id}`)
      .then((res) => {
        return res?.data?.data;
      })
      .catch((error) => {
        if (error.response.status != 409) throw error;
        router.push("/verify-email");
      })
  );

  const getAllFavoriteModels= async({...props})=>{
    HttpService.get(`/model/favorite-list?visitor_id=${visitor_id}`)
    .then((res) => {
      props.setFavoriteList(res.data.data)
      return res?.data?.data;
    })
    .catch((error) => {
      if (error.response.status != 409) throw error;
      router.push("/verify-email");
    })
  }
  const addModelToFavoriteList = async ({
    setErrors,
    ...props
  }) => {
    //send model application  post request
    HttpService.post("/add/model/favorites", props, {
      Headers: {
        "Content-type": "application/json",
      },
    })
      .then((response) => {
        if (response?.status === 200) {
          //mode is
          if(response.data.data){
            router.push('/favorites')
          }
        }
      })
      .catch((error) => {
        console.log("[error]", error);
        if (error.response.status != 422) throw error;
        setErrors(Object.values(error.response.data.errors).flat());
      });
  };


  const removeModelFormFavoriteList = async ({
    setErrors,
    ...props
  }) => {
    //send model application  post request
    HttpService.delete(`/remove/model/${props.model_id}/${visitor_id}`, {
      Headers: {
        "Content-type": "application/json",
      },
    })
      .then((response) => {
        if (response?.status === 200) {
          //mode is
          if(response.data.data){
            props.setRemoveModelSuccess(true)
            router.push('/favorites')
          }
        }
      })
      .catch((error) => {
        console.log("[error]", error);
        if (error.response.status != 422) throw error;
        setErrors(Object.values(error.response.data.errors).flat());
      });
  };




  useEffect(() => {
    if (typeof window !== 'undefined') { // Check if running in the browser
        const visitorId = localStorage.getItem('visitor_id');
        setVisitorId(visitorId);
    }

  }, [favoriteModels, error]);

  return {
    favoriteModels,
    getAllFavoriteModels,
    addModelToFavoriteList,
    removeModelFormFavoriteList
  };
};
