import useSWR from "swr";
import { useEffect } from "react";
import { useRouter } from "next/router";
import HttpService from "@/services/HttpService";
export const useModelPhoto = () => {
  //use router to redirect   
  const router = useRouter();
  //use swr to fetch models data
  const {
    data: allModels,
    error,
    revalidate,
  } = useSWR("/admin/all/model", async () =>
    HttpService.get("/admin/all/model")
      .then((res) => {
        return res?.data?.data;
      })
      .catch((error) => {
        if (error.response.status != 409) throw error;
        router.push("/verify-email");
      })
  );

  const fetchAllModelPhotos=async(setAllModelPhotos)=>{
    await HttpService.get("/admin/all/model")
    .then((res) => {
      setAllModelPhotos(res?.data?.data)
      // return res?.data?.data;
    })
    .catch((error) => {
      if (error.response.status != 409) throw error;
      router.push("/verify-email");
    })
  }


  const addModelPhoto = async ({
    setInputs,
    setLoading,
    setErrors,
    image_url,
    model_id,
    orientation,
  }) => {
    //send model application  post request
    setLoading(true);

    //define data
    const formData = new FormData();

    formData.append("image_url", image_url);
    formData.append("model_id", model_id);
    formData.append("orientation", orientation);

    //console
    console.log("Form Data");
    for (let obj of formData) {
      console.log(obj);
    }

    HttpService.post("/admin/add/model/photo", formData, {
      Headers: {
        "Content-type": "multipart/form-data",
      },
    })
      .then((response) => {
        if (response?.status === 200) {
          setLoading(false);
          //mode is
          setInputs({
            image: null,
            model_id: null,
            orientation: "",
          });
          router.push('/admin/model-photo/list')
        }
      })
      .catch((error) => {
        console.log("[error]", error);
        if (error.response.status != 422) throw error;
        setErrors(Object.values(error.response.data.errors).flat());
      });
  };

  const deleteModelPhoto = async ({ ...props }) => {

    props.setLoading(true);

    HttpService.delete(`/admin/model/photo/${props.model_id}/${props.image_id}`, {
      headers: {
        "Content-Type": "application/json",
      },
    })
      .then((response) => {
        if (response?.status === 200) {
          console.log("[model-delete]", response.data);
          props.setDeleteModelPhotoSuccess(response.data.data);
          props.setLoading(false);
        }
      })
      .catch((error) => {
        props.setDeleteModelPhotoSuccess(false);
        props.setLoading(false);
        alert(Object.values(error.response.data.errors).flat());
      });
  };



  useEffect(() => {}, [allModels, error]);

  return {
    allModels,
    fetchAllModelPhotos,
    addModelPhoto,
    deleteModelPhoto
  };
};
