import AllModels from "@/components/models/AllModels";
import AppLayout from "@/components/UI/layout/app/AppLayout";
import React from "react";
import queryString from "query-string";

const ModelsPage = ({ models, gender, startsWith }) => {
  return (
    <AppLayout>
      <AllModels models={models} gender={gender} startsWith={startsWith} />
    </AppLayout>
  );
};

export const getServerSideProps = async (context) => {
  //backend api url
  const apiUrl = process.env.NEXT_PUBLIC_BACKEND_URL;
  //get query params
  const { gender, startsWith } = context.query;
  //if query params has gender and starts with
  if (gender || startsWith) {
    //create url params object
    const urlParams = {
      gender: gender,
      startsWith: startsWith,
    };
    //create search query params object
    const searchParams = queryString.stringify(urlParams);
    //if search params not equals to empty string
    if (searchParams !== "") {
      //fetch model api url
      const url = `${apiUrl}/models?${searchParams}`;
      //fetch models by search params
      const res = await fetch(url, {
        method: "GET",
        headers: {
          "Content-Type": "application/json; charset=utf-8",
          Accept: "application/json",
        },
        credentials: "include",
        withCredentials: true,
      });
      //response has an error
      if (!res.ok) {
        console.log("Error");
      }
      //get models response
      const models = await res?.json();
      console.log("[models]", models);
      //pass data to the page via props
      return {
        props: {
          models: models || [],
          gender: gender || null,
          startsWith: startsWith || null,
        },
      };
    }
  }
  //if no query params
  const res = await fetch(`${apiUrl}/models`, {
    method: "GET",
    headers: {
      "Content-Type": "application/json; charset=utf-8",
    },
    credentials: "include",
    withCredentials: true,
  });
  //response has error message
  if (!res.ok) {
    console.log("Error");
  }
  //get all models data form api response
  const models = await res?.json();
  //pass data to page via props
  return { props: { models } };
};

export default ModelsPage;
